@@ -182,7 +182,10 @@ def make_wrapper_simple_client(instance, **kwargs):
 
 def _custom_wrapper_wrap_internal(wrappee, **kwargs):
     if not callable(wrappee):
-        return CustomWrapper(wrappee, **kwargs)
+        if isinstance(wrappee, dict):
+            return WrapperDict(wrappee, **kwargs)
+        else:
+            return CustomWrapper(wrappee, **kwargs)
     return wrappee
 
 
@@ -214,6 +217,11 @@ class CustomWrapper(wrapt.ObjectProxy):
     def __deepcopy__(self, memodict={}):
         return _custom_wrapper_wrap_internal(copy.deepcopy(self.__wrappee__, memodict))
 
+    @property
+    def __dict__(self):
+        return self.__wrappee__.__dict__
+
 
 def make_custom_wrapper_client(wrappee, **kwargs):
-    return _custom_wrapper_wrap_internal(wrappee, callback=_make_wrapper_simple_client_callback, **kwargs)
+    kwargs['callback'] = _make_wrapper_simple_client_callback
+    return _custom_wrapper_wrap_internal(wrappee, **kwargs)
